@@ -46,7 +46,7 @@ function (x, order = c(1, 1), series = NULL, control = garch.control(...), ...)
     if(!is.vector(coef)) stop("coef is not a vector")
     if(ncoef != length(coef)) stop("incorrect length of coef")
     nlikeli <- 1.0e+10
-    fit <- .C("fit_garch",
+    fit <- .C(R_fit_garch,
               as.vector(x, mode = "double"),
               as.integer(n),
               coef = as.vector(coef, mode = "double"),
@@ -59,25 +59,22 @@ function (x, order = c(1, 1), series = NULL, control = garch.control(...), ...)
 	      as.double(control$falsetol),
               nlikeli = as.double(nlikeli),
               as.integer(agrad),
-              as.integer(control$trace),
-              PACKAGE="tseries")
-    pred <- .C("pred_garch",
+              as.integer(control$trace))
+    pred <- .C(R_pred_garch,
                as.vector(x, mode = "double"),
                e = as.vector(e, mode = "double"),
                as.integer(n),
                as.vector(fit$coef, mode = "double"),
                as.integer(order[1]),
                as.integer(order[2]),
-               as.integer(FALSE),
-               PACKAGE = "tseries")
-    com.hess <- .C("ophess_garch",
+               as.integer(FALSE))
+    com.hess <- .C(R_ophess_garch,
                    as.vector(x, mode = "double"),
                    as.integer(n),
                    as.vector(fit$coef, mode = "double"),
                    hess = as.matrix(hess),
                    as.integer(order[1]),
-                   as.integer(order[2]),
-                   PACKAGE="tseries")
+                   as.integer(order[2]))
     rank <- do.call("qr", c(list(x = com.hess$hess), control$qr))$rank
     if(rank != ncoef) {
 	vc <- matrix(NA, nrow = ncoef, ncol = ncoef)
@@ -260,15 +257,14 @@ function(object, newdata, genuine = FALSE, ...)
     n <- nrow(newdata)
     if(genuine) h <- double(n+1)
     else h <- double(n)
-    pred <- .C("pred_garch",
+    pred <- .C(R_pred_garch,
                as.vector(newdata, mode = "double"),
                h = as.vector(h, mode = "double"),
                as.integer(n),
                as.vector(object$coef, mode = "double"),
                as.integer(object$order[1]),
                as.integer(object$order[2]),
-               as.integer(genuine),
-               PACKAGE="tseries")
+               as.integer(genuine))
     pred$h <- sqrt(pred$h)
     pred$h[1:max(object$order[1],object$order[2])] <-
         rep.int(NA, max(object$order[1],object$order[2]))
